#!/bin/sh
#
# by Chih-Wei Huang
# modified by Pablo Saratxaga <pablo@mandrakesoft.com>
#
#              Updated   22-24 July - 24 August 1999
#        Last modified   5 January 2000
#

#PATH="/bin:/usr/bin:/usr/X11R6/bin:/usr/local/bin"
SCRIPTNAME=`basename $0`

RXVT=/usr/X11R6/bin/rxvt.bin

if [ "$SCRIPTNAME" = "rxvt" -o "$SCRIPTNAME" = "rxvt.sh" ]; then
    if [ ! -z $LC_ALL ]; then
        locale=$LC_ALL
    elif [ ! -z $LC_CTYPE ]; then
        locale=$LC_CTYPE
    elif [ ! -z $LANG ]; then
        locale=$LANG
    fi

    case $locale in
        zh_TW*)
        SCRIPTNAME=crxvt
        ;;

        zh_CN*)
        SCRIPTNAME=gbrxvt
	;;

	ja*)
	SCRIPTNAME=jrxvt
	;;

	ko*)
	SCRIPTNAME=krxvt
	;;

      # unknown locale, ignore it
        *)
	MENU=""
        ;;
    esac

    unset locale
fi

case $SCRIPTNAME in
    crxvt)
    LANG=zh_TW.Big5
    ENC=big5
    XA_FACE=ming
    XA_FAMILY=default
    XIM=xcin
    MENU="/usr/X11R6/lib/X11/rxvt/rxvt-zh;big5"
    FMFONT="-default-ming-medium-r-normal--16-*-*-*-c-160-big5-0"
  # FNFONT="-schumacher-clean-bold-r-normal--16-160-75-75-c-80-iso8859-1"
    _TITLE="Chinese"
    ;;

    gbrxvt)
    LANG=zh_CN.GB2312
    ENC=gb
    XA_FACE=ming
    XA_FAMILY=default
    XIM=xcin-zh_CN.GB2312
    MENU="/usr/X11R6/lib/X11/rxvt/rxvt-zh;gb"
    FMFONT="-default-ming-medium-r-normal--16-*-*-*-c-160-gb2312.1980-0"
    _TITLE="Chinese"
    ;;

    jrxvt)
    LANG=ja
    ENC=eucj
    XA_FACE=fixed
    XA_FAMILY=default
    XIM=kinput2
    #MENU="/usr/share/rxvt/rxvt-ja;eucj"
    _TITLE="Japanese"
    ;;

    krxvt)
    LANG=ko
    ENC=kr
    XA_FACE=fixed
    XA_FAMILY=default
    XIM=Ami
    #MENU="/usr/share/rxvt/rxvt-ko;kr"
    _TITLE="Korean"
    ;;
	
esac

export LANG

FGCOLOR=lightgray
BGCOLOR=black
TITLE="$_TITLE RXVT ($LANG)"

ARGS=""

while [ -n "$1" ]; do
    case $1 in
        -km) shift
        ENC=$1
        ;;

        -im) shift
        XIM=$1
        ;;

        -fg) shift
        FGCOLOR=$1
        ;;

        -bg) shift
        BGCOLOR=$1
        ;;

        -T|-title) shift
        TITLE=$1
        ;;

        -menu) shift
        MENU="$1"
        ;;

        -nomenu)
        MENU=""
        ;;

        -fn) shift
        FNFONT="$1"
        ;;

        -fm) shift
        FMFONT="$1"
        ;;

        *)
        ARGS="$ARGS $1"
        ;;
    esac
    shift
done

[ -n "$BGCOLOR" ] && ARGS="-bg $BGCOLOR $ARGS"
[ -n "$FGCOLOR" ] && ARGS="-fg $FGCOLOR $ARGS"
[ -n "$ENC" ] && ARGS="-km $ENC $ARGS"
if [ -n "$XIM" ]; then
    ARGS="-im $XIM $ARGS"
    export XMODIFIERS="@im=$XIM"
fi

# Alas! Dirty hack for font name containing spaces
# Is there any simpler solution??
if [ -n "$FNFONT" -a -n "$FMFONT" ]; then
    exec $RXVT -T "$TITLE" -menu "$MENU" -fn "$FNFONT" -fm "$FMFONT" $ARGS
elif [ -n "$FNFONT" ]; then
    exec $RXVT -T "$TITLE" -menu "$MENU" -fn "$FNFONT" $ARGS
elif [ -n "$FMFONT" ]; then
    exec $RXVT -T "$TITLE" -menu "$MENU" -fm "$FMFONT" $ARGS
else
    exec $RXVT -T "$TITLE" -menu "$MENU" $ARGS
fi
